<?php

require_once(dirname(__FILE__).'/cache.php');
require_once(dirname(__FILE__).'/config.php');
require_once(dirname(__FILE__).'/interface.php');
require_once(dirname(__FILE__).'/option.php');
require_once(dirname(__FILE__).'/postmeta.php');
require_once(dirname(__FILE__).'/runtime.php');

// ----------------------------------------------------------------------------
// the DiscloseSecret_Manager class handles the plugin initialization phase,
// assuring the infrastructure is set up properly
// ----------------------------------------------------------------------------

class DiscloseSecret_Manager
{
	var $m_allowed_wp_versions = array('2.0.4');
	var $m_cache;
	var $m_runtime;
	var $m_interface;

	// ----------------------------------------------------------------------------
	// init
	// ----------------------------------------------------------------------------

	function DiscloseSecret_Manager()
	{
		// Just in case someone's loaded up the page standalone for whatever reason,
		// make sure it doesn't crash in an ugly way
		if (function_exists('load_plugin_textdomain'))
			load_plugin_textdomain(DiscloseSecret_PLUGIN_ID, DiscloseSecret_DIR);

		global $wp_version;
		if (!isset($wp_version))
			die(__('This page must be loaded as part of WordPress', DiscloseSecret_PLUGIN_ID));

		if (!in_array($wp_version, $this->m_allowed_wp_versions))
			die(sprintf(__('The %s plugin was only tested with the following WordPress versions: ', DiscloseSecret_PLUGIN_ID), DiscloseSecret_PLUGIN_NAME). implode(', ', $this->m_allowed_wp_versions));

		$this->m_cache = new DiscloseSecret_Cache();
		add_filter('init', array(&$this, 'init'));
	}

	function init()
	{
		// don't bother with anything more unless someone is logged in
		if (is_user_logged_in())
		{
			// make sure private pages aren't cached publicly
			header('Cache-Control: private');
			header('Pragma: no-cache');

			$this->m_runtime = new DiscloseSecret_Runtime($this->m_cache);
			$this->m_interface = new DiscloseSecret_Interface($this->m_cache);
		}
	}

	function &get_cache()
	{
		return $this->m_cache;
	}
}

?>